@@ -47,7 +47,8 @@ OptimizerGridSearch = R6Class("OptimizerGridSearch", inherit = Optimizer,
       super$initialize(
         param_set = param_set,
         param_classes = c("ParamLgl", "ParamInt", "ParamDbl", "ParamFct"),
-        properties = c("dependencies", "single-crit", "multi-crit")
+        properties = c("dependencies", "single-crit", "multi-crit"),
+        man = "bbotk::mlr_optimizers_grid_search"
       )
     }
   ),
