@@ -105,7 +105,9 @@ OptimizerNLoptr = R6Class("OptimizerNLoptr", inherit = Optimizer,
         param_set = param_set,
         param_classes = "ParamDbl",
         properties = "single-crit",
-        packages = "nloptr")
+        packages = "nloptr",
+        man = "bbotk::mlr_optimizers_nloptr"
+      )
     }
   ),
 
