@@ -13,8 +13,8 @@ test_that("TerminatorPerfReached in OptimInstanceMultiCrit throws an error", {
   expect_error(MAKE_INST_2D_2D(terminator))
 })
 
-test_that("TerminatorPerfReached works with empty archive" ,{
+test_that("TerminatorPerfReached works with empty archive", {
   terminator = TerminatorPerfReached$new()
-  archive = Archive$new(ps(x = p_dbl()), ps(y = p_dbl()))
+  archive = Archive$new(ps(x = p_dbl()), ps(y = p_dbl(tags = "minimize")))
   expect_false(terminator$is_terminated(archive))
 })
