@@ -13,8 +13,8 @@ test_that("TerminatorStagnation in OptimInstanceMultiCrit throws an error", {
   expect_error(MAKE_INST_2D_2D(terminator))
 })
 
-test_that("TerminatorStagnation works with empty archive" ,{
+test_that("TerminatorStagnation works with empty archive", {
   terminator = TerminatorStagnation$new()
-  archive = Archive$new(ps(x = p_dbl()), ps(y = p_dbl()))
+  archive = Archive$new(ps(x = p_dbl()), ps(y = p_dbl(tags = "minimize")))
   expect_false(terminator$is_terminated(archive))
-})
\ No newline at end of file
+})
